"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
const googleMapRegExp = /^(?<left>.*?)\[(?<latitude>([NS]\d+(\.\d+)?),(?<longitude>[EW]\d+(\.\d+)?)(?<zoom>(,Z\d+)?))(?<place>)\](?<right>.*)$/;
const leftGoogleMapRegExp = /^(?<left>.*?)\[(?<place>[^\]]*[^\s])\s+(?<latitude>([NS]\d+(\.\d+)?),(?<longitude>[EW]\d+(\.\d+)?)(?<zoom>(,Z\d+)?))\](?<right>.*)$/;
const rightGoogleMapRegExp = /^(?<left>.*?)\[(?<latitude>([NS]\d+(\.\d+)?),(?<longitude>[EW]\d+(\.\d+)?)(?<zoom>(,Z\d+)?))\s+(?<place>[^\]]*[^\s])\](?<right>.*)$/;
const isGoogleMapMatch = (obj) => (obj && obj.groups && obj.groups.latitude);
const createGoogleMapNode = (_latitude, _longitude, _zoom, place) => {
    const latitude = parseFloat(_latitude.replace(/^N/, '').replace(/^S/, '-'));
    const longitude = parseFloat(_longitude.replace(/^E/, '').replace(/^W/, '-'));
    const zoom = parseInt(_zoom.replace(/^,Z/, '') || '14', 10);
    const url = place
        ? `https://www.google.com/maps/place/${encodeURIComponent(place)}/@${latitude},${longitude},${zoom}z`
        : `https://www.google.com/maps/@${latitude},${longitude},${zoom}z`;
    return {
        type: 'googleMap',
        latitude,
        longitude,
        zoom,
        place,
        url
    };
};
exports.GoogleMapNodeParser = (text, { nested, quoted }, next) => {
    if (nested)
        return next();
    const googleMapMatch = text.match(googleMapRegExp) ||
        text.match(leftGoogleMapRegExp) ||
        text.match(rightGoogleMapRegExp);
    if (!isGoogleMapMatch(googleMapMatch))
        return next();
    const { left, latitude, longitude, zoom, place, right } = googleMapMatch.groups;
    return [
        ..._1.convertToLineNodes(left, { nested, quoted }),
        createGoogleMapNode(latitude, longitude, zoom, place),
        ..._1.convertToLineNodes(right, { nested, quoted })
    ];
};
//# sourceMappingURL=GoogleMapNode.js.map